==> igniteui-angular-charts-18.0.0.tgz: package/esm5/lib/TRIXIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { TRIXIndicatorStrategy } from "./TRIXIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
import { Brush } from "igniteui-angular-core";
/**
 * @hidden
 */
var TRIXIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TRIXIndicator, _super);
    function TRIXIndicator() {
        var _this = _super.call(this) || this;
        _this.zi = 0;
        _this.trendLineBrush = ((function () {
            var $ret = new Brush();
            $ret.fill = "#565656";
            return $ret;
        })());
        _this.trendLineType = 9;
        _this.trendLinePeriod = 9;
        return _this;
    }
    TRIXIndicator.prototype.bb = function () {
        return new TRIXIndicator();
    };
    TRIXIndicator.prototype.get_aaa = function () {
        return new TRIXIndicatorStrategy();
    };
    Object.defineProperty(TRIXIndicator.prototype, "aaa", {
        get: function () {
            return this.get_aaa();
        },
        enumerable: false,
        configurable: true
    });
    TRIXIndicator.prototype.get_aan = function () {
        return TRIXIndicator.$;
    };
    Object.defineProperty(TRIXIndicator.prototype, "aan", {
        get: function () {
            return this.get_aan();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TRIXIndicator.prototype, "aav", {
        get: function () {
            return typeGetValue(this.c(TRIXIndicator.aaw));
        },
        set: function (a) {
            this.h(TRIXIndicator.aaw, a);
        },
        enumerable: false,
        configurable: true
    });
    TRIXIndicator.prototype.aag = function () {
        return this.aav;
    };
    TRIXIndicator.prototype.aap = function (a) {
        this.aav = a;
    };
    TRIXIndicator.$t = markType(TRIXIndicator, 'TRIXIndicator', StrategyBasedIndicator.$);
    TRIXIndicator.aaw = StrategyBasedIndicator.aas(15, TRIXIndicator.$);
    return TRIXIndicator;
}(StrategyBasedIndicator));
export { TRIXIndicator };

==> igniteui-angular-charts-18.1.0.tgz: package/esm5/lib/TRIXIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { TRIXIndicatorStrategy } from "./TRIXIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
import { Brush } from "igniteui-angular-core";
/**
 * @hidden
 */
var TRIXIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TRIXIndicator, _super);
    function TRIXIndicator() {
        var _this = _super.call(this) || this;
        _this.aau = 0;
        _this.trendLineBrush = ((function () {
            var $ret = new Brush();
            $ret.fill = "#565656";
            return $ret;
        })());
        _this.trendLineType = 9;
        _this.trendLinePeriod = 9;
        return _this;
    }
    TRIXIndicator.prototype.bi = function () {
        return new TRIXIndicator();
    };
    TRIXIndicator.prototype.get_abm = function () {
        return new TRIXIndicatorStrategy();
    };
    Object.defineProperty(TRIXIndicator.prototype, "abm", {
        get: function () {
            return this.get_abm();
        },
        enumerable: false,
        configurable: true
    });
    TRIXIndicator.prototype.get_abz = function () {
        return TRIXIndicator.$;
    };
    Object.defineProperty(TRIXIndicator.prototype, "abz", {
        get: function () {
            return this.get_abz();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TRIXIndicator.prototype, "ab7", {
        get: function () {
            return typeGetValue(this.c(TRIXIndicator.ab8));
        },
        set: function (a) {
            this.h(TRIXIndicator.ab8, a);
        },
        enumerable: false,
        configurable: true
    });
    TRIXIndicator.prototype.abs = function () {
        return this.ab7;
    };
    TRIXIndicator.prototype.ab1 = function (a) {
        this.ab7 = a;
    };
    TRIXIndicator.$t = markType(TRIXIndicator, 'TRIXIndicator', StrategyBasedIndicator.$);
    TRIXIndicator.ab8 = StrategyBasedIndicator.ab4(15, TRIXIndicator.$);
    return TRIXIndicator;
}(StrategyBasedIndicator));
export { TRIXIndicator };
